@@ -102,7 +102,7 @@ repository = %(repository_path)s
           os.killpg(pgpid, signal.SIGTERM)
         except:
           pass
-      while true:
+      while True:
         try:
           process_group_pid_set.pop()
         except KeyError:
